pub enum SwapAmountMsg {
Points {
long: f64,
short: f64,
},
Currency {
long: f64,
short: f64,
currency: String,
},
}Expand description
Wire-safe nightly swap magnitude, where a negative value charges and a positive value credits.
Variants
Points
Price points per lot per night, in the instrument’s native currency.
Currency
Amount per lot per night, in the run’s account currency.