pub struct GetBacktestResultResponse {
pub success: bool,
pub job_id: String,
pub result: Option<BacktestResultMsg>,
pub error: Option<String>,
pub artifact: Option<ResultArtifactRefMsg>,
pub inline_complete: bool,
pub artifact_consumed: bool,
}Expand description
Response containing the result of a completed backtest job.
Fields
success: booljob_id: Stringresult: Option<BacktestResultMsg>error: Option<String>artifact: Option<ResultArtifactRefMsg>inline_complete: boolartifact_consumed: boolTrue when an async result artifact was deleted after delivery.