pub struct PortfolioOutputMsg {
pub instances: Vec<PortfolioInstanceOutputMsg>,
pub policies: Option<Value>,
pub supervisor: Option<Value>,
}Expand description
Instance and supervisor output returned with a portfolio run’s shared economic result.
Fields
instances: Vec<PortfolioInstanceOutputMsg>policies: Option<Value>The decoded policies and groups the run was supervised with, when it had a supervisor.
supervisor: Option<Value>Every review, halt action, and halt interval, when the run had a supervisor.